export declare enum Tags {
    /**
     * Abbreviation or Acronym
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/abbrev.html
     */
    'abbrev' = "abbrev",
    /**
     * Abstract
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/abstract.html
     */
    'abstract' = "abstract",
    /**
     * Access Date for Cited Work
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/access-date.html
     */
    'accessDate' = "access-date",
    /**
     * Acknowledgments
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/ack.html
     */
    'ack' = "ack",
    /**
     * Address Line
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/addr-line.html
     */
    'addrLine' = "addr-line",
    /**
     * Address/Contact Information
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/address.html
     */
    'address' = "address",
    /**
     * Affiliation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/aff.html
     */
    'aff' = "aff",
    /**
     * Affiliation Alternatives
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/aff-alternatives.html
     */
    'affAlternatives' = "aff-alternatives",
    /**
     * Free to Read (NISO Access and License  Indicators)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/ali-free_to_read.html
     */
    'ali:free_to_read' = "ali:free_to_read",
    /**
     * License Reference (NISO and Access License  Indicators)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/ali-license_ref.html
     */
    'ali:license_ref' = "ali:license_ref",
    /**
     * Alternate Text Name (for a figure, etc.)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/alt-text.html
     */
    'altText' = "alt-text",
    /**
     * Alternate Title
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/alt-title.html
     */
    'altTitle' = "alt-title",
    /**
     * Alternatives For Processing
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/alternatives.html
     */
    'alternatives' = "alternatives",
    /**
     * Annotation in a Citation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/annotation.html
     */
    'annotation' = "annotation",
    /**
     * Anonymous
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/anonymous.html
     */
    'anonymous' = "anonymous",
    /**
     * Answer to a Question
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/answer.html
     */
    'answer' = "answer",
    /**
     * Answer Set
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/answer-set.html
     */
    'answerSet' = "answer-set",
    /**
     * Appendix
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/app.html
     */
    'app' = "app",
    /**
     * Appendix Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/app-group.html
     */
    'appGroup' = "app-group",
    /**
     * Array (Simple Tabulation)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/array.html
     */
    'array' = "array",
    /**
     * Article
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/article.html
     */
    'article' = "article",
    /**
     * Article Metadata
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/article-meta.html
     */
    'articleMeta' = "article-meta",
    /**
     * Article Title
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/article-title.html
     */
    'articleTitle' = "article-title",
    /**
     * Article Current Version Status or Number
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/article-version.html
     */
    'articleVersion' = "article-version",
    /**
     * Attribution
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/attrib.html
     */
    'attrib' = "attrib",
    /**
     * Author Comment
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/author-comment.html
     */
    'authorComment' = "author-comment",
    /**
     * Award Description
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/award-desc.html
     */
    'awardDesc' = "award-desc",
    /**
     * Award Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/award-group.html
     */
    'awardGroup' = "award-group",
    /**
     * Award Identifier
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/award-id.html
     */
    'awardId' = "award-id",
    /**
     * Award Name
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/award-name.html
     */
    'awardName' = "award-name",
    /**
     * Back Matter
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/back.html
     */
    'back' = "back",
    /**
     * Biography
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/bio.html
     */
    'bio' = "bio",
    /**
     * Body of the Document
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/body.html
     */
    'body' = "body",
    /**
     * Bold
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/bold.html
     */
    'bold' = "bold",
    /**
     * Boxed Text
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/boxed-text.html
     */
    'boxedText' = "boxed-text",
    /**
     * Line Break
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/break.html
     */
    'break' = "break",
    /**
     * Caption of a Figure, Table, etc.
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/caption.html
     */
    'caption' = "caption",
    /**
     * Chapter Title in a Citation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/chapter-title.html
     */
    'chapterTitle' = "chapter-title",
    /**
     * Chemical Structure (Display)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/chem-struct.html
     */
    'chemStruct' = "chem-struct",
    /**
     * Chemical Structure Wrapper
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/chem-struct-wrap.html
     */
    'chemStructWrap' = "chem-struct-wrap",
    /**
     * Citation Alternatives
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/citation-alternatives.html
     */
    'citationAlternatives' = "citation-alternatives",
    /**
     * City
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/city.html
     */
    'city' = "city",
    /**
     * Code
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/code.html
     */
    'code' = "code",
    /**
     * Table Column (NISO JATS table model)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/col.html
     */
    'col' = "col",
    /**
     * Table Column Group (NISO JATS table model)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/colgroup.html
     */
    'colgroup' = "colgroup",
    /**
     * Collaborative (Group) Author
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/collab.html
     */
    'collab' = "collab",
    /**
     * Collaboration Alternatives
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/collab-alternatives.html
     */
    'collabAlternatives' = "collab-alternatives",
    /**
     * Comment in a Citation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/comment.html
     */
    'comment' = "comment",
    /**
     * Compound Keyword
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/compound-kwd.html
     */
    'compoundKwd' = "compound-kwd",
    /**
     * Compound Keyword Part
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/compound-kwd-part.html
     */
    'compoundKwdPart' = "compound-kwd-part",
    /**
     * Compound Subject Name
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/compound-subject.html
     */
    'compoundSubject' = "compound-subject",
    /**
     * Compound Subject Part Name
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/compound-subject-part.html
     */
    'compoundSubjectPart' = "compound-subject-part",
    /**
     * Conference Acronym
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/conf-acronym.html
     */
    'confAcronym' = "conf-acronym",
    /**
     * Conference Date
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/conf-date.html
     */
    'confDate' = "conf-date",
    /**
     * Conference Location
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/conf-loc.html
     */
    'confLoc' = "conf-loc",
    /**
     * Conference Name
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/conf-name.html
     */
    'confName' = "conf-name",
    /**
     * Conference Number
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/conf-num.html
     */
    'confNum' = "conf-num",
    /**
     * Conference Sponsor
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/conf-sponsor.html
     */
    'confSponsor' = "conf-sponsor",
    /**
     * Conference Theme
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/conf-theme.html
     */
    'confTheme' = "conf-theme",
    /**
     * Conference Information
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/conference.html
     */
    'conference' = "conference",
    /**
     * Contributor
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/contrib.html
     */
    'contrib' = "contrib",
    /**
     * Contributor Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/contrib-group.html
     */
    'contribGroup' = "contrib-group",
    /**
     * Contributor Identifier
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/contrib-id.html
     */
    'contribId' = "contrib-id",
    /**
     * Contributed Resource Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/contributed-resource-group.html
     */
    'contributedResourceGroup' = "contributed-resource-group",
    /**
     * Copyright Holder
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/copyright-holder.html
     */
    'copyrightHolder' = "copyright-holder",
    /**
     * Copyright Statement
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/copyright-statement.html
     */
    'copyrightStatement' = "copyright-statement",
    /**
     * Copyright Year
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/copyright-year.html
     */
    'copyrightYear' = "copyright-year",
    /**
     * Country: in an Address
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/country.html
     */
    'country' = "country",
    /**
     * Custom Metadata
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/custom-meta.html
     */
    'customMeta' = "custom-meta",
    /**
     * Custom Metadata Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/custom-meta-group.html
     */
    'customMetaGroup' = "custom-meta-group",
    /**
     * Data Title
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/data-title.html
     */
    'dataTitle' = "data-title",
    /**
     * Date
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/date.html
     */
    'date' = "date",
    /**
     * Date within a Citation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/date-in-citation.html
     */
    'dateInCitation' = "date-in-citation",
    /**
     * Day
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/day.html
     */
    'day' = "day",
    /**
     * Definition List: Definition
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/def.html
     */
    'def' = "def",
    /**
     * Definition List: Definition Head
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/def-head.html
     */
    'defHead' = "def-head",
    /**
     * Definition List: Definition Item
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/def-item.html
     */
    'defItem' = "def-item",
    /**
     * Definition List
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/def-list.html
     */
    'defList' = "def-list",
    /**
     * Degree(s)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/degrees.html
     */
    'degrees' = "degrees",
    /**
     * Formula, Display
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/disp-formula.html
     */
    'dispFormula' = "disp-formula",
    /**
     * Formula, Display Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/disp-formula-group.html
     */
    'dispFormulaGroup' = "disp-formula-group",
    /**
     * Quote, Displayed
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/disp-quote.html
     */
    'dispQuote' = "disp-quote",
    /**
     * Edition Statement, Cited
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/edition.html
     */
    'edition' = "edition",
    /**
     * Element Citation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/element-citation.html
     */
    'elementCitation' = "element-citation",
    /**
     * Electronic Location Identifier
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/elocation-id.html
     */
    'elocationId' = "elocation-id",
    /**
     * Email Address
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/email.html
     */
    'email' = "email",
    /**
     * Era of Time
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/era.html
     */
    'era' = "era",
    /**
     * Et Al.
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/etal.html
     */
    'etal' = "etal",
    /**
     * Explanation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/explanation.html
     */
    'explanation' = "explanation",
    /**
     * External Link
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/ext-link.html
     */
    'extLink' = "ext-link",
    /**
     * Extended-by Model
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/extended-by.html
     */
    'extendedBy' = "extended-by",
    /**
     * Fax Number: in an Address
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/fax.html
     */
    'fax' = "fax",
    /**
     * Figure
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/fig.html
     */
    'fig' = "fig",
    /**
     * Fixed Case
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/fixed-case.html
     */
    'fixedCase' = "fixed-case",
    /**
     * Footnote
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/fn.html
     */
    'fn' = "fn",
    /**
     * Footnote Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/fn-group.html
     */
    'fnGroup' = "fn-group",
    /**
     * First Page
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/fpage.html
     */
    'fpage' = "fpage",
    /**
     * Front Matter
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/front.html
     */
    'front' = "front",
    /**
     * Funding Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/funding-group.html
     */
    'fundingGroup' = "funding-group",
    /**
     * Funding Source
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/funding-source.html
     */
    'fundingSource' = "funding-source",
    /**
     * Funding Statement
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/funding-statement.html
     */
    'fundingStatement' = "funding-statement",
    /**
     * Given (First) Names
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/given-names.html
     */
    'givenNames' = "given-names",
    /**
     * Glossary Elements List
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/glossary.html
     */
    'glossary' = "glossary",
    /**
     * Glyph Data for a Private Character
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/glyph-data.html
     */
    'glyphData' = "glyph-data",
    /**
     * Glyph Reference for a Private Character
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/glyph-ref.html
     */
    'glyphRef' = "glyph-ref",
    /**
     * Government Report, Cited
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/gov.html
     */
    'gov' = "gov",
    /**
     * Graphic
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/graphic.html
     */
    'graphic' = "graphic",
    /**
     * Horizontal Rule
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/hr.html
     */
    'hr' = "hr",
    /**
     * Index Term
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/index-term.html
     */
    'indexTerm' = "index-term",
    /**
     * Index Term Range End
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/index-term-range-end.html
     */
    'indexTermRangeEnd' = "index-term-range-end",
    /**
     * Formula, Inline
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/inline-formula.html
     */
    'inlineFormula' = "inline-formula",
    /**
     * Graphic, Inline
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/inline-graphic.html
     */
    'inlineGraphic' = "inline-graphic",
    /**
     * Inline Media Object
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/inline-media.html
     */
    'inlineMedia' = "inline-media",
    /**
     * Inline Supplementary Material Metadata
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/inline-supplementary-material.html
     */
    'inlineSupplementaryMaterial' = "inline-supplementary-material",
    /**
     * Institution Name: in an Address
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/institution.html
     */
    'institution' = "institution",
    /**
     * Institution Identifier
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/institution-id.html
     */
    'institutionId' = "institution-id",
    /**
     * Institution Wrapper
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/institution-wrap.html
     */
    'institutionWrap' = "institution-wrap",
    /**
     * ISBN
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/isbn.html
     */
    'isbn' = "isbn",
    /**
     * ISSN International Standard Serial Number
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/issn.html
     */
    'issn' = "issn",
    /**
     * ISSN-L (Linking ISSN)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/issn-l.html
     */
    'issn-l' = "issn-l",
    /**
     * Issue Number
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/issue.html
     */
    'issue' = "issue",
    /**
     * Issue Identifier
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/issue-id.html
     */
    'issueId' = "issue-id",
    /**
     * Issue Part
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/issue-part.html
     */
    'issuePart' = "issue-part",
    /**
     * Issue Title
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/issue-title.html
     */
    'issueTitle' = "issue-title",
    /**
     * Italic
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/italic.html
     */
    'italic' = "italic",
    /**
     * Journal Identifier
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/journal-id.html
     */
    'journalId' = "journal-id",
    /**
     * Keyword
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/kwd.html
     */
    'kwd' = "kwd",
    /**
     * Keyword Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/kwd-group.html
     */
    'kwdGroup' = "kwd-group",
    /**
     * Label (of an Equation, Figure, Reference, etc.)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/label.html
     */
    'label' = "label",
    /**
     * License Information
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/license.html
     */
    'license' = "license",
    /**
     * License Paragraph
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/license-p.html
     */
    'license-p' = "license-p",
    /**
     * List
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/list.html
     */
    'list' = "list",
    /**
     * List Item
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/list-item.html
     */
    'listItem' = "list-item",
    /**
     * Long Description
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/long-desc.html
     */
    'longDesc' = "long-desc",
    /**
     * Last Page
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/lpage.html
     */
    'lpage' = "lpage",
    /**
     * Media Object
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/media.html
     */
    'media' = "media",
    /**
     * Metadata Data Name for Custom Metadata
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/meta-name.html
     */
    'metaName' = "meta-name",
    /**
     * Metadata Data Value for Custom Metadata
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/meta-value.html
     */
    'metaValue' = "meta-value",
    /**
     * Mixed Citation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/mixed-citation.html
     */
    'mixedCitation' = "mixed-citation",
    /**
     * Math (MathML Tag Set)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/mml-math.html
     */
    'mml:math' = "mml:math",
    /**
     * Monospace Text (Typewriter Text)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/monospace.html
     */
    'monospace' = "monospace",
    /**
     * Month
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/month.html
     */
    'month' = "month",
    /**
     * Name of Person
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/name.html
     */
    'name' = "name",
    /**
     * Name Alternatives
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/name-alternatives.html
     */
    'nameAlternatives' = "name-alternatives",
    /**
     * Named Special (Subject) Content
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/named-content.html
     */
    'namedContent' = "named-content",
    /**
     * Nested Keyword
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/nested-kwd.html
     */
    'nestedKwd' = "nested-kwd",
    /**
     * NLM Citation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/nlm-citation.html
     */
    'nlmCitation' = "nlm-citation",
    /**
     * Object Identifier
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/object-id.html
     */
    'objectId' = "object-id",
    /**
     * On Behalf of
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/on-behalf-of.html
     */
    'onBehalfOf' = "on-behalf-of",
    /**
     * Open Access
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/open-access.html
     */
    'openAccess' = "open-access",
    /**
     * Answer Option (for a question)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/option.html
     */
    'option' = "option",
    /**
     * Overline
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/overline.html
     */
    'overline' = "overline",
    /**
     * Paragraph
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/p.html
     */
    'p' = "p",
    /**
     * Page Count
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/page-count.html
     */
    'pageCount' = "page-count",
    /**
     * Page Ranges
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/page-range.html
     */
    'pageRange' = "page-range",
    /**
     * Part Title in a Citation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/part-title.html
     */
    'partTitle' = "part-title",
    /**
     * Patent Number, Cited
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/patent.html
     */
    'patent' = "patent",
    /**
     * Permissions
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/permissions.html
     */
    'permissions' = "permissions",
    /**
     * Person Group for a Cited Publication
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/person-group.html
     */
    'personGroup' = "person-group",
    /**
     * Phone Number: in an Address
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/phone.html
     */
    'phone' = "phone",
    /**
     * Postal Code
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/postal-code.html
     */
    'postalCode' = "postal-code",
    /**
     * Prefix
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/prefix.html
     */
    'prefix' = "prefix",
    /**
     * Preformatted Text
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/preformat.html
     */
    'preformat' = "preformat",
    /**
     * Price
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/price.html
     */
    'price' = "price",
    /**
     * Principal Award Recipient
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/principal-award-recipient.html
     */
    'principalAwardRecipient' = "principal-award-recipient",
    /**
     * Principal Investigator
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/principal-investigator.html
     */
    'principalInvestigator' = "principal-investigator",
    /**
     * Private Character (Custom or Unicode)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/private-char.html
     */
    'privateChar' = "private-char",
    /**
     * Processing Metadata
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/processing-meta.html
     */
    'processingMeta' = "processing-meta",
    /**
     * Product Information
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/product.html
     */
    'product' = "product",
    /**
     * Publication Identifier for a Cited Publication
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/pub-id.html
     */
    'pubId' = "pub-id",
    /**
     * Publisher’s Location
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/publisher-loc.html
     */
    'publisherLoc' = "publisher-loc",
    /**
     * Publisher’s Name
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/publisher-name.html
     */
    'publisherName' = "publisher-name",
    /**
     * Question
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/question.html
     */
    'question' = "question",
    /**
     * Question Preamble
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/question-preamble.html
     */
    'questionPreamble' = "question-preamble",
    /**
     * Question Wrapper
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/question-wrap.html
     */
    'questionWrap' = "question-wrap",
    /**
     * Question Wrapper Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/question-wrap-group.html
     */
    'questionWrapGroup' = "question-wrap-group",
    /**
     * Ruby Base Text
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/rb.html
     */
    'rb' = "rb",
    /**
     * Reference Item
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/ref.html
     */
    'ref' = "ref",
    /**
     * Reference List (Bibliographic)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/ref-list.html
     */
    'refList' = "ref-list",
    /**
     * Related Article Information
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/related-article.html
     */
    'relatedArticle' = "related-article",
    /**
     * Related Object Information
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/related-object.html
     */
    'relatedObject' = "related-object",
    /**
     * Resource Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/resource-group.html
     */
    'resourceGroup' = "resource-group",
    /**
     * Resource Identifier
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/resource-id.html
     */
    'resourceId' = "resource-id",
    /**
     * Resource Name
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/resource-name.html
     */
    'resourceName' = "resource-name",
    /**
     * Resource Wrap
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/resource-wrap.html
     */
    'resourceWrap' = "resource-wrap",
    /**
     * Restricted-by Model
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/restricted-by.html
     */
    'restrictedBy' = "restricted-by",
    /**
     * Role or Function Title of Contributor
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/role.html
     */
    'role' = "role",
    /**
     * Roman
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/roman.html
     */
    'roman' = "roman",
    /**
     * Ruby Textual Annotation
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/rt.html
     */
    'rt' = "rt",
    /**
     * Ruby Annotation Wrapper
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/ruby.html
     */
    'ruby' = "ruby",
    /**
     * Sans Serif
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/sans-serif.html
     */
    'sansSerif' = "sans-serif",
    /**
     * Small Caps
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/sc.html
     */
    'sc' = "sc",
    /**
     * Season
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/season.html
     */
    'season' = "season",
    /**
     * Section
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/sec.html
     */
    'sec' = "sec",
    /**
     * Section Metadata
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/sec-meta.html
     */
    'secMeta' = "sec-meta",
    /**
     * See
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/see.html
     */
    'see' = "see",
    /**
     * See-Also
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/see-also.html
     */
    'seeAlso' = "see-also",
    /**
     * URI for This Same Article Online
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/self-uri.html
     */
    'selfUri' = "self-uri",
    /**
     * Series
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/series.html
     */
    'series' = "series",
    /**
     * Size
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/size.html
     */
    'size' = "size",
    /**
     * Source
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/source.html
     */
    'source' = "source",
    /**
     * Speaker
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/speaker.html
     */
    'speaker' = "speaker",
    /**
     * Speech
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/speech.html
     */
    'speech' = "speech",
    /**
     * State or Province
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/state.html
     */
    'state' = "state",
    /**
     * Statement, Formal
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/statement.html
     */
    'statement' = "statement",
    /**
     * Standard, Cited
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/std.html
     */
    'std' = "std",
    /**
     * Standards Organization
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/std-organization.html
     */
    'stdOrganization' = "std-organization",
    /**
     * Strike Through
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/strike.html
     */
    'strike' = "strike",
    /**
     * Date as a String
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/string-date.html
     */
    'stringDate' = "string-date",
    /**
     * Name of Person (Unstructured)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/string-name.html
     */
    'stringName' = "string-name",
    /**
     * Styled Special (Subject) Content
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/styled-content.html
     */
    'styledContent' = "styled-content",
    /**
     * Subscript
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/sub.html
     */
    'sub' = "sub",
    /**
     * Subject Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/subj-group.html
     */
    'subjGroup' = "subj-group",
    /**
     * Subject Grouping Name
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/subject.html
     */
    'subject' = "subject",
    /**
     * Document Subtitle
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/subtitle.html
     */
    'subtitle' = "subtitle",
    /**
     * Suffix
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/suffix.html
     */
    'suffix' = "suffix",
    /**
     * Superscript
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/sup.html
     */
    'sup' = "sup",
    /**
     * Supplement Information
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/supplement.html
     */
    'supplement' = "supplement",
    /**
     * Supplementary Material Metadata
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/supplementary-material.html
     */
    'supplementaryMaterial' = "supplementary-material",
    /**
     * Support Description
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/support-description.html
     */
    'supportDescription' = "support-description",
    /**
     * Support Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/support-group.html
     */
    'supportGroup' = "support-group",
    /**
     * Support Source
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/support-source.html
     */
    'supportSource' = "support-source",
    /**
     * Surname
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/surname.html
     */
    'surname' = "surname",
    /**
     * Table (NISO JATS table model)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/table.html
     */
    'table' = "table",
    /**
     * Table Wrapper
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/table-wrap.html
     */
    'tableWrap' = "table-wrap",
    /**
     * Table Wrapper Footer
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/table-wrap-foot.html
     */
    'tableWrapFoot' = "table-wrap-foot",
    /**
     * Target of an Internal Link
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/target.html
     */
    'target' = "target",
    /**
     * Table Body (NISO JATS table model)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/tbody.html
     */
    'tbody' = "tbody",
    /**
     * Table Data Cell (NISO JATS table model)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/td.html
     */
    'td' = "td",
    /**
     * Definition List: Term
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/term.html
     */
    'term' = "term",
    /**
     * Definition List: Term Head
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/term-head.html
     */
    'termHead' = "term-head",
    /**
     * Textual Form
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/textual-form.html
     */
    'textualForm' = "textual-form",
    /**
     * Table Footer (NISO JATS table model)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/tfoot.html
     */
    'tfoot' = "tfoot",
    /**
     * Table Header Cell (NISO JATS table model)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/th.html
     */
    'th' = "th",
    /**
     * Table Header (NISO JATS table model)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/thead.html
     */
    'thead' = "thead",
    /**
     * Time Stamp for Cited Work
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/time-stamp.html
     */
    'timeStamp' = "time-stamp",
    /**
     * Title
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/title.html
     */
    'title' = "title",
    /**
     * Title Group
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/title-group.html
     */
    'titleGroup' = "title-group",
    /**
     * Table Row (NISO JATS table model)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/tr.html
     */
    'tr' = "tr",
    /**
     * Translated Source
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/trans-source.html
     */
    'transSource' = "trans-source",
    /**
     * Translated Title
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/trans-title.html
     */
    'transTitle' = "trans-title",
    /**
     * Underline
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/underline.html
     */
    'underline' = "underline",
    /**
     * Uniform Resource Identifier (URI)
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/uri.html
     */
    'uri' = "uri",
    /**
     * Verse Form for Poetry
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/verse-group.html
     */
    'verseGroup' = "verse-group",
    /**
     * Line of a Verse
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/verse-line.html
     */
    'verseLine' = "verse-line",
    /**
     * Version Statement
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/version.html
     */
    'version' = "version",
    /**
     * Volume Number
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/volume.html
     */
    'volume' = "volume",
    /**
     * Volume Identifier
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/volume-id.html
     */
    'volumeId' = "volume-id",
    /**
     * Volume Series
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/volume-series.html
     */
    'volumeSeries' = "volume-series",
    /**
     * X (cross) Reference
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/xref.html
     */
    'xref' = "xref",
    /**
     * Year
     * See: https://jats.nlm.nih.gov/articleauthoring/tag-library/1.3/element/year.html
     */
    'year' = "year",
    /**
     * Sub Article
     *
     * Not available in articleauthoring!
     *
     * See: https://jats.nlm.nih.gov/publishing/tag-library/1.3/element/sub-article.html
     */
    'subArticle' = "sub-article",
    /**
     * Article Identifier
     *
     * Not available in articleauthoring!
     *
     * See: https://jats.nlm.nih.gov/publishing/tag-library/1.3/element/article-id.html
     */
    'articleId' = "article-id",
    /**
     * Publication Date
     *
     * Not available in articleauthoring!
     *
     * See: https://jats.nlm.nih.gov/publishing/tag-library/1.3/element/pub-date.html
     */
    'pubDate' = "pub-date",
    /**
     * Article Grouping Data
     *
     * Not available in articleauthoring!
     *
     * See: https://jats.nlm.nih.gov/archiving/tag-library/1.3/element/article-categories.html
     */
    'articleCategories' = "article-categories",
    /**
     * Journal Title
     *
     * Not available in articleauthoring!
     *
     * See: https://jats.nlm.nih.gov/archiving/tag-library/1.3/element/journal-title.html
     */
    'journalTitle' = "journal-title"
}
//# sourceMappingURL=elementTags.d.ts.map